==> cfblog-0.1.3.zip: cfblog-0.1.3/cfblog/migrations/0002_create_static_page_category.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import warnings

from django.db import migrations


def create_static_page_category(apps, schema_editor):
    Category = apps.get_model('cfblog', 'Category')
    print '\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>'
    print 'Creating the static pages category'
    if Category.objects.filter(id=1):
        warnings.warn(
            "Entry for static pages already exists."
        )
    else:
        Category.objects.create(
            id=1,
            title='Static Page',
            description='All the standalone pages should be under this category'
        )
    print '<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<'


def delete_static_page_category(apps, schema_editor):
    Category = apps.get_model('cfblog', 'Category')
    categories = Category.objects.filter(id=1)
    print '\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>'
    print 'Deleting the static pages category'
    if categories:
        categories.delete()
    else:
        warnings.warn(
            "Entry for static pages does not exist."
        )
    print '<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<'


class Migration(migrations.Migration):

    dependencies = [
        ('cfblog', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(
            code=create_static_page_category,
            reverse_code=delete_static_page_category
        )
    ]

==> cfblog-0.2.3.zip: cfblog-0.2.3/cfblog/migrations/0002_create_static_page_category.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import warnings

from django.core.management.color import no_style
from django.db import migrations


def create_static_page_category(apps, schema_editor):
    Category = apps.get_model('cfblog', 'Category')
    print '\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>'
    print 'Creating the static pages category'
    if Category.objects.filter(id=1):
        warnings.warn(
            "Entry for static pages already exists."
        )
    else:
        reset_sequence = True
        if Category.objects.count():
            reset_sequence = False

        Category.objects.create(
            id=1,
            title='Static Page',
            description='All the standalone pages should be under this category'
        )

        if reset_sequence:
            connection = schema_editor.connection
            sql_statements = connection.ops.sequence_reset_sql(no_style(), [Category])
            operation = migrations.RunSQL(sql=sql_statements)
            operation.database_forwards('cfblog', schema_editor, None, None)

    print '<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<'


def delete_static_page_category(apps, schema_editor):
    Category = apps.get_model('cfblog', 'Category')
    categories = Category.objects.filter(id=1)
    print '\n>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>'
    print 'Deleting the static pages category'
    if categories:
        categories.delete()
    else:
        warnings.warn(
            "Entry for static pages does not exist."
        )
    print '<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<'


class Migration(migrations.Migration):

    dependencies = [
        ('cfblog', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(
            code=create_static_page_category,
            reverse_code=delete_static_page_category
        )
    ]
